vmshepherd.iaas package
=======================

Submodules
----------

vmshepherd.iaas.abstract module
-------------------------------

.. automodule:: vmshepherd.iaas.abstract
    :members:
    :undoc-members:
    :show-inheritance:

vmshepherd.iaas.dummy\_driver module
------------------------------------

.. automodule:: vmshepherd.iaas.dummy_driver
    :members:
    :undoc-members:
    :show-inheritance:

vmshepherd.iaas.exception module
--------------------------------

.. automodule:: vmshepherd.iaas.exception
    :members:
    :undoc-members:
    :show-inheritance:

vmshepherd.iaas.openstack\_driver module
----------------------------------------

.. automodule:: vmshepherd.iaas.openstack_driver
    :members:
    :undoc-members:
    :show-inheritance:

vmshepherd.iaas.vm module
-------------------------

.. automodule:: vmshepherd.iaas.vm
    :members:
    :undoc-members:
    :show-inheritance:
    :noindex:


Module contents
---------------

.. automodule:: vmshepherd.iaas
    :members:
    :undoc-members:
    :show-inheritance:
